 // 文本
 var TEXT_SYSTEM_ERROR = '系统异常';
 var TEXT_NO_NET = '网络异常';
 var TEXT_NO_MORE = '无更多数据';
 var TEXT_NO_DATA = '没有数据';

 // 特殊文本
 var TEXT_BIND_MEDICAL_CARD = '请先绑定您的医疗卡';
 var TEXT_GET_ACCOUNT_FAIL = '获取医保卡余额失败';

 // 日期格式化默认格式
 var TIME_FORMAT = 'yyyy-MM-dd';

 /**
  * 获取预约列表接口从医院返回值中获取有用的信息
  * @param response
  * @returns {*}
  */
 function getInfoFromHospitalResponse(response) {
 	if(response.NewDataSet && response.NewDataSet.Table) {
 		return response.NewDataSet.Table;
 	} else {
 		return undefined;
 	}
 }

 /**
  * 类alert，用户必须点击确认，必须执行回调
  * @param {string} message
  * @param {function} [callback]
  */
 var alertDialog = function(message, callback) {
 	// 单例
 	if($('.yt-dialog').length != 0) return;

 	var alertDialogObj = new DialogWidget({
 		content: message,
 		btns: ['确认'],
 		isMaskDefault: false
 	});
 	alertDialogObj.click(function() {
 		alertDialogObj.remove();
 		callback && callback();
 	});
 };

 /**
  * 类confirm，用户点击确认后执行回调
  * @param {string} message
  * @param {function} [callback]
  */
 var confirmDialog = function(message, callback) {
 	// 单例
 	if($('.yt-dialog').length != 0) return;

 	var confirmDialogObj = new DialogWidget({
 		content: message,
 		btns: ['取消', '确认'],
 		callback: function(index) {
 			if(index === 1 && callback) callback();
 		},
 		isMaskDefault: true
 	});
 	confirmDialogObj.click(function(index) {
 		if(index === 1 && callback) callback();
 		confirmDialogObj.remove();
 	});
 };

 /**
  * 对话框
  * @param options
  * @constructor
  */
 var DialogWidget = function(options) {
 	// 默认值，由于存在弹出框后再弹弹出框，所以延迟只能为0
 	this.opts = $.extend({
 		title: '提示',
 		content: '内容',
 		btns: ['取消', '确认'],
 		isMaskDefault: true,
 		duration: 0
 	}, options);

 	// 遮罩
 	this.$mask = $('<div class="yt-dialog-mask" style="display: none"></div>');
 	// 对话框
 	this.$selector = $('<div class="yt-dialog" style="display: none"></div>');

 	this.init();
 };

 /**
  * 初始化
  */
 DialogWidget.prototype.init = function() {
 	var thisWidget = this;
 	var opts = this.opts;
 	var $mask = this.$mask;
 	var $selector = this.$selector;

 	// 先清空对话框
 	$selector.html('');
 	// 标题
 	if(opts.title) {
 		$selector.append('<div class="yt-dialog-hd"><div class="yt-dialog-title">' + opts.title + '</div></div>');
 	}
 	// 内容
 	$selector.append('<div class="yt-dialog-bd">' + opts.content + '</div>');
 	// 按钮
 	var $foot = $('<div class="yt-dialog-ft"></div>');
 	for(var i = 0; i < opts.btns.length; i++) {
 		$foot.append('<a class="yt-dialog-btn" href="javascript:void(0);">' + opts.btns[i] + '</a>');
 	}
 	$selector.append($foot);
 	// 添加控件
 	$('body').append($mask).append($selector);
 	$mask.fadeIn(opts.duration);
 	$selector.fadeIn(opts.duration);

 	// 点击遮罩移除对话框
 	$mask.off('tap touchmove').on('tap touchmove', function() {
 		thisWidget.opts.isMaskDefault && thisWidget.remove();
 	});
 };

 /**
  * 移除
  */
 DialogWidget.prototype.remove = function() {
 	var thisWidget = this;
 	thisWidget.$mask.fadeOut(thisWidget.opts.duration);
 	thisWidget.$selector.fadeOut(thisWidget.opts.duration, function() {
 		thisWidget.$mask.remove();
 		thisWidget.$selector.remove();
 	});
 };

 /**
  * 点击事件
  * @param callback
  */
 DialogWidget.prototype.click = function(callback) {
 	$('.yt-dialog-btn').off('tap').on('tap', function() {
 		callback($(this).index());
 	});
 };

 /**
  * 从医院返回的接口中获取医疗卡号
  * @response 绑定接口返回的结果
  */
 var getMedicalCardNum = function(response) {
 	return response.result.NewDataSet.Table.PatientID;
 };

 /**
  * 添加模板辅助方法
  */
 var addTemplateHelper = function() {
 	/**
 	 * 电话添加星号
 	 */
 	template.helper('addPhoneNumAsterisk', function(val) {
 		var len = val.length;
 		if(val.length != 11) return val;

 		var start = val.substring(0, 3);
 		var end = val.substring(len - 4);
 		return start + '****' + end;
 	});

 	/**
 	 * 身份证添加星号
 	 */
 	template.helper('addIDNumAsterisk', function(val) {
 		var len = val.length;
 		if(len === 15 || len === 18) {
 			var start = val.substring(0, 4);
 			var end = val.substring(len - 4);
 			return start + (len === 18 ? '**********' : '*******') + end;
 		} else {
 			return val;
 		}
 	});

 	/**
 	 * 把身份证转换为生日
 	 */
 	template.helper('translateIDNumToBirthday', function(val) {
 		var len = val.length;
 		if(len === 18) {
 			var year = val.substr(6, 4);
 			var month = val.substr(10, 2);
 			var day = val.substr(12, 2);
 			var birthday = year + '-' + month + '-' + day;
 			// 			return new Date(birthday).format(TIME_FORMAT);
 			return birthday;
 		} else {
 			return '未知';
 		}
 	});
 };

 /**
  * 验证医疗卡号
  * @param val
  * @returns {boolean}
  */
 var checkMedicalCardNum = function(val) {
 	if(/^[a-zA-Z0-9]{1,30}$/.test(val)) {
 		return true;
 	} else {
 		//toast('医疗卡号只能为字母和数字');
 		topmobi.native.common.showMsg("医疗卡号只能为字母和数字", "middle", toastTimeForMedicalCard);
 		return false;
 	}
 };

 /**
  * 验证地址
  * @param val
  * @returns {boolean}
  */
 var checkAddress = function(val) {
 	if(/^[\s\S]{1,50}$/.test(val)) {
 		return true;
 	} else {
 		//toast('地址长度只能为1-50位');
 		topmobi.native.common.showMsg("地址长度只能为1-50位", "middle", toastTimeForMedicalCard);
 		return false;
 	}
 };

 /**
  * 异步获取就诊卡号
  * @param options
  *     {String} token 必选
  *     {Function} success 成功时回调
  */

 var asyncGetPatientId = function(options) {
 	/**
 	 * 从返回值中获取医疗卡号
 	 * @param response
 	 * @returns {*}
 	 */
 	var getPatientIdFromResponse = function(response) {
 		return response.result.NewDataSet.Table.PatientID;
 	};

 	var obj = {
 		url: hospitalTestUrl + 'reg',
 		isEncrypt: true,
 		data: {
 			token: options.token,
 			phoneNum: options.phoneNum
 		},
 		success: function(response) {
 			var result = response.result;
 			if(result.Result) {
 				switch(result.Result.ResultCode) {
 					case '0':
 						// 注册成功
 					case '2':
 						// 身份证号和卡号已注册 返回his号
 					case '3':
 						// his号认证成功
 					case '4':
 						// 身份证号更新成功
 						options.success({
 							code: '200',
 							patientId: getPatientIdFromResponse(response)
 						});

 						break;
 					default:
 						// 未绑定医疗卡
 						options.success({
 							code: '404'
 						});
 						break;
 				}
 			} else if(result.msg) {
 				topmobi.native.common.showMsg(result.msg, "middle", toastTimeForMedicalCard);
 			} else {
 				topmobi.native.common.showMsg(TEXT_SYSTEM_ERROR, "middle", toastTimeForMedicalCard);
 			}
 		}
 	}
 	rs_networkRequest(obj);

 };

 /**
  * 异步获取个人信息
  * @param options
  *     {String} token 必选
  * *     {String} phoneNum 必选
  *     {Function} success 成功时回调
  */

 var asyncGetUserInfo = function(options) {
 	var dataJson = {
 		"handler": "q001Handler",
 		"token": options.token,
 	};
 	var obj = {
 		url: medicalUrl,
 		data: dataJson,
 		method: "post",
 		isEncrypt: true,
 		success: function(response) {
 			if(response.result) {
 				response = response.result;
 				switch (response.code) {
          case '1':
            // 获取成功  解析姓名、身份证号、电话号码
            var userinfo = response.output;
            topmobi.native.cache.putSharedValue('user', 'nickName', userinfo.aac003); //与登录返回的信息不同，这里的名字不带*
            topmobi.native.cache.putSharedValue('user', 'identityNum', userinfo.aac002); //这里的身份证号不带*
            //查询个人参保信息成功
            topmobi.native.cache.putSharedValue('user', 'medicalSocailCardId', userinfo.aac001); //aac001  个人编号,测试必须，正式通过token获取
            topmobi.native.cache.putSharedValue('user', 'medicalSocailCardNum', userinfo.aaz501); //社保卡号  aaz501
            topmobi.native.cache.putSharedValue('user', 'medicalAccountBalance', userinfo.yka065); //医保个人账户余额 yka065
            topmobi.native.cache.putSharedValue('user', 'medicalBindFlag', userinfo.aae119); //是否已在本机构绑定社会保障卡aae119
            topmobi.native.cache.putSharedValue('user', 'medicalInstitute', userinfo.aab034); //参保经办机构  aab034
            topmobi.native.cache.putSharedValue('user', 'hasGetUserSocialInfo', '1'); //是否获取过个人参保信息
            if (typeof options.success == 'function') {
              options.success({ code: '200' });
            }
            break;
          default: {
            if (!options.silence) {
              var msg = response.msg || '获取个人信息失败！'
              topmobi.native.common.showMsg(msg, 'middle', toastTimeForMedicalCard);
            }
            options.fail && options.fail(response);
          }
        }
 			} else {
        if (!options.silence) {
          topmobi.native.common.showMsg("获取个人信息失败！", "middle", toastTimeForMedicalCard);
        }
         options.fail && options.fail(response);
 			}
 		},
 		fail: function(data) {
       topmobi.native.common.log('getMedicalAccount', '错误：' + JSON.stringify(data));
       if (typeof options.fail == 'function') {
         options.fail(data);
       }
 		}
 	}
 	rs_networkRequest(obj);
 };

 /**
  * 异步获取个人参保信息
  * @param options
  *     {String} userName 必选
  * *     {String} identityNum 必选
  *     {Function} success 成功时回调
  */

 var asyncGetUserSocialInfo = function(options) {
 	var dataJson = {
 		"handler": "q001Handler",
 		"sub": {
 			"aac002": options.identityNum,
 			"aac003": options.userName
 		}
 	};
 	var obj = {
 		url: medicalUrl,
 		method: "post",
 		isEncrypt: true,
 		data: dataJson,
 		success: function(data) {
 			var result = data.result;
 			if(result.code && result.code == "1") {
 				//查询个人参保信息成功
 				topmobi.native.cache.putSharedValue("user", "medicalSocailCardId", result.output.aac001); //aac001  个人编号,测试必须，正式通过token获取
 				topmobi.native.cache.putSharedValue("user", "medicalSocailCardNum", result.output.aaz501); //社保卡号  aaz501
 				topmobi.native.cache.putSharedValue("user", "medicalAccountBalance", result.output.yka065); //医保个人账户余额 yka065
 				topmobi.native.cache.putSharedValue("user", "medicalBindFlag", result.output.aae119); //是否已在本机构绑定社会保障卡aae119
 				topmobi.native.cache.putSharedValue("user", "medicalInstitute", result.output.aab034); //参保经办机构  aab034 
 				topmobi.native.cache.putSharedValue("user", "hasGetUserSocialInfo", "1"); //是否获取过个人参保信息
 				options.success({
 					code: '200'
 				});
 			} else {
 				if(!!data.result && !!data.result.message) {
 					//未查找到符合条件的数据也返回200，走这个分支，并将错误信息写入data.result.message
 					topmobi.native.common.showMsg(data.result.message, "middle", toastTimeForMedicalCard);
 					return;
 				}
 				topmobi.native.common.showMsg("获取个人参保信息失败！", "middle", toastTimeForMedicalCard);
 			}
 		},
 		fail: function(data) {
 			topmobi.native.common.log("getMedicalAccount", "错误：" + JSON.stringify(data));
 		}
 	}
 	rs_networkRequest(obj);
 };

 //	/*
 //	 * 根据手机号码获取个人信息 (姓名\身份证号\电话号码等)
 //	 */
 //	function getUserInfo(phoneNum,token) {
 //		var dataJson = {
 //			"handler":"getUserInfoHandler",
 //			"token": token,
 //			 "sub": {
 //			 	"phoneNum":phoneNum
 //			 }
 //		};
 //		var obj = {
 //			url: hospitalTestUrl+'appointment',
 //			method: "post",
 ////			isEncrypt: true,
 //			data: dataJson,
 //			success: function(response) {
 //				response = response.result;
 //				switch(response.code) {
 //					case '1000':
 //					     // 获取成功  解析姓名、身份证号、电话号码
 //					    var userInfo = response.data;
 //					    var userName = userInfo.nickName;
 //						var identityNum = userInfo.identityNum;
 //						topmobi.native.cache.putSharedValue("user", "nickName", userName);//与登录返回的信息不同，这里的名字不带*
 //						topmobi.native.cache.putSharedValue("user", "idCardNumber", identityNum);//这里的身份证号不带*
 //						getPersonalSocialInfo(userName,identityNum);
 //						break;
 //				}
 //			},
 //			fail: function(data) {
 //				topmobi.native.common.log("getMedicalAccount", "错误：" + JSON.stringify(data));
 //			}
 //		}
 //		rs_networkRequest(obj);
 //	};

 //	/*
 //	 *根据userName 和identifyNum来查询个人参保信息 
 //	 */
 //	function getPersonalSocialInfo(userName,identityNum){
 //		var dataJson = {
 //			"handler":"q001Handler",
 //			"sub":{
 //				"aac002": identityNum,
 //				"aac003":userName
 //			}			
 //		};
 //		var obj = {
 //			url: medicalUrl,
 //			method: "post",
 //			isEncrypt: true,
 //			data: dataJson,
 //			success: function(data) {
 //				var result = data.result;
 //				if(result.code  && result.code=="1") {				
 //					//查询个人参保信息成功
 //					topmobi.native.cache.putSharedValue("user", "medicalSocailCardId", result.output.aac001);//aac001  个人编号,测试必须，正式通过token获取
 //					topmobi.native.cache.putSharedValue("user", "medicalSocailCardNum", result.output.aaz501);//社保卡号  aaz501
 //					topmobi.native.cache.putSharedValue("user", "medicalBalance", result.output.yka065);//医保个人账户余额 yka065
 //					topmobi.native.cache.putSharedValue("user", "medicalBindFlag", result.output.aae119);//是否已在本机构绑定社会保障卡aae119
 //					topmobi.native.cache.putSharedValue("user", "medicalInstitute", result.output.aab034);//参保经办机构  aab034 
 //				} else {
 //					if(!!data.result && !!data.result.message) {
 //						//未查找到符合条件的数据也返回200，走这个分支，并将错误信息写入data.result.message
 //						topmobi.native.common.showMsg(data.result.message, "middle", toastTimeForMedicalCard);
 //						return;
 //					}
 //					topmobi.native.common.showMsg("获取个人参保信息失败！", "middle", toastTimeForMedicalCard);
 //				}
 //			},
 //			fail: function(data) {
 //				topmobi.native.common.log("getPersonalSocialInfo", "错误：" + JSON.stringify(data));
 //			}
 //		}
 //		rs_networkRequest(obj);
 //	}